pub enum LatestEventValue {
None,
RoomMessage(SyncRoomMessageEvent),
Sticker(SyncStickerEvent),
Poll(SyncUnstablePollStartEvent),
CallInvite(SyncCallInviteEvent),
CallNotify(SyncCallNotifyEvent),
KnockedStateEvent(SyncRoomMemberEvent),
}Expand description
A latest event value!
Variants
None
No value has been computed yet, or no candidate value was found.
RoomMessage(SyncRoomMessageEvent)
A m.room.message event.
Sticker(SyncStickerEvent)
A m.sticker event.
Poll(SyncUnstablePollStartEvent)
An org.matrix.msc3381.poll.start event.
CallInvite(SyncCallInviteEvent)
A m.call.invite event.
CallNotify(SyncCallNotifyEvent)
A m.call.notify event.
KnockedStateEvent(SyncRoomMemberEvent)
A m.room.member event, more precisely a knock membership change that
can be handled by the current user.